==> curia-4.2.0b7.tar.gz: curia-4.2.0b7/src/curia/api/docs/ModelJobResponseDto.md <==
# ModelJobResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project** | [**ModelJobJoinedProjectResponseDto**](ModelJobJoinedProjectResponseDto.md) |  | [optional] 
**outputs** | [**ModelJobJoinedModelJobOutputResponseDto**](ModelJobJoinedModelJobOutputResponseDto.md) |  | [optional] 
**model_population** | [**ModelJobJoinedModelPopulationResponseDto**](ModelJobJoinedModelPopulationResponseDto.md) |  | [optional] 
**feature_sub_categories** | [**ModelJobJoinedFeatureSubCategoryResponseDto**](ModelJobJoinedFeatureSubCategoryResponseDto.md) |  | [optional] 
**dataset** | [**ModelJobJoinedDatasetResponseDto**](ModelJobJoinedDatasetResponseDto.md) |  | [optional] 
**cohort** | [**ModelJobJoinedCohortResponseDto**](ModelJobJoinedCohortResponseDto.md) |  | [optional] 
**model** | [**ModelJobJoinedModelResponseDto**](ModelJobJoinedModelResponseDto.md) |  | [optional] 
**model_job_statuses** | [**ModelJobJoinedModelJobStatusResponseDto**](ModelJobJoinedModelJobStatusResponseDto.md) |  | [optional] 
**outcome_distribution_histogram_query** | [**ModelJobJoinedDataQueryResponseDto**](ModelJobJoinedDataQueryResponseDto.md) |  | [optional] 
**id** | **str** |  | [optional] 
**type** | **str** |  | 
**outcome_type** | **str** |  | [optional] 
**config** | [**ModelJobConfig**](ModelJobConfig.md) |  | [optional] 
**execution_id** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**project_id** | **str** |  | 
**model_id** | **str** |  | 
**cohort_id** | **str** |  | [optional] 
**dataset_id** | **str** |  | [optional] 
**model_population_id** | **str** |  | [optional] 
**outcome_distribution_histogram_query_id** | **str** |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**started_at** | **datetime** |  | [optional] 
**ended_at** | **datetime** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> curia-4.6.0.tar.gz: curia-4.6.0/src/curia/api/docs/ModelJobResponseDto.md <==
# ModelJobResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project** | [**ModelJobJoinedProjectResponseDto**](ModelJobJoinedProjectResponseDto.md) |  | [optional] 
**outputs** | [**list[ModelJobJoinedModelJobOutputResponseDto]**](ModelJobJoinedModelJobOutputResponseDto.md) |  | [optional] 
**model_population** | [**ModelJobJoinedModelPopulationResponseDto**](ModelJobJoinedModelPopulationResponseDto.md) |  | [optional] 
**feature_sub_categories** | [**list[ModelJobJoinedFeatureSubCategoryResponseDto]**](ModelJobJoinedFeatureSubCategoryResponseDto.md) |  | [optional] 
**dataset** | [**ModelJobJoinedDatasetResponseDto**](ModelJobJoinedDatasetResponseDto.md) |  | [optional] 
**cohort** | [**ModelJobJoinedCohortResponseDto**](ModelJobJoinedCohortResponseDto.md) |  | [optional] 
**model** | [**ModelJobJoinedModelResponseDto**](ModelJobJoinedModelResponseDto.md) |  | [optional] 
**model_job_statuses** | [**list[ModelJobJoinedModelJobStatusResponseDto]**](ModelJobJoinedModelJobStatusResponseDto.md) |  | [optional] 
**outcome_distribution_histogram_query** | [**ModelJobJoinedDataQueryResponseDto**](ModelJobJoinedDataQueryResponseDto.md) |  | [optional] 
**id** | **str** |  | [optional] 
**type** | **str** |  | 
**outcome_type** | **str** |  | [optional] 
**config** | [**ModelJobConfig**](ModelJobConfig.md) |  | [optional] 
**execution_id** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**project_id** | **str** |  | 
**model_id** | **str** |  | 
**cohort_id** | **str** |  | [optional] 
**dataset_id** | **str** |  | [optional] 
**model_population_id** | **str** |  | [optional] 
**outcome_distribution_histogram_query_id** | **str** |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**started_at** | **datetime** |  | [optional] 
**ended_at** | **datetime** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
